Struct rs_graph::adapters::network::Network[][src]

pub struct Network<'a, G>(_);

The network graph adaptor.

It is meant to be used by borrowing the underlying graph.

let g = classes::cycle::<LinkedListGraph>(5);
let n = Network::new(&g);

The network inherits all trait implementations from the underlying graph. In particular, if the underlying graph implements IndexGraph then nodes and edges of the network are numbered, too:

  • The node_id is the same as in the underlying graph,
  • the edge with id i is mapped to the edges 2*i (forward edge) and 2*i+1 (backward edge).

Implementations

impl<'a, G> Network<'a, G> where
    G: Digraph<'a>, 
[src]

pub fn new(g: &'a G) -> Self[src]

Create a new network adapter wrapping g.

pub fn as_graph(&self) -> &'a G[src]

Return a reference to the underlying graph.

pub fn from_edge(&self, e: G::Edge) -> NetworkEdge<G::Edge>[src]

Return the forward edge corresponding the edge e in the underlying graph.