Struct rs_graph::attributed::Attributed[][src]

pub struct Attributed<G, Gx = (), Nx = (), Ex = ()> { /* fields omitted */ }
👎 Deprecated since 0.17.0:

use rs-graph-derive crate instead

Wrapper to attach attributes with a graph.

This is a wrapper struct that adds additional attributes to an arbitrary graph. The type parameters are

  • ’Gx` the type of graph attributes.
  • ’Nx` the type of node attributes.
  • ’Ex` the type of edge attributes.
  • ’Ax` the type of biedge attributes.

The attributed graph implements Graph, Digraph and Network if the the wrapped graph does.

Example

use rs_graph::{LinkedListGraph, classes, traits::*};
use rs_graph::attributed::{Attributes, Attributed, AttributedGraph};

#[derive(Default)]
struct NodeAttr {
    balance: f64,
}

#[derive(Default)]
struct EdgeAttr {
    flow: f64,
}

type MyGraph = Attributed<LinkedListGraph, (), NodeAttr, EdgeAttr>;
let mut g: MyGraph = classes::complete_bipartite(3,4);

{
    let (g, mut attr) = g.split();
    for u in g.nodes() {
        attr.node_mut(u).balance = 42.0;
    }
    for e in g.edges() {
        attr.edge_mut(e).flow = 1.5;
    }
}

assert!(g.nodes().all(|u| g.node(u).balance == 42.0));
assert!(g.edges().all(|e| g.edge(e).flow == 1.5));