Struct rs_graph::attributed::AttributedBuilder[][src]

pub struct AttributedBuilder<B, Gx, Nx, Ex>(_, _);
👎 Deprecated since 0.17.0:

use rs-graph-derive crate instead

Default builder for an attributes graph.

This builder requires the attributes to be default constructable. All attributes will be initialized with these default values.