Struct rs_graph::collections::ItemVecMap[][src]

pub struct ItemVecMap<'a, I, V> { /* fields omitted */ }

A thin wrapper around a ItemVec<_, Option<V>>.

Such a vector can be used as ItemMap<_, V> with a field being None if and only if the corresponding key is not contained in the map.

Implementations

impl<'a, I, V> ItemVecMap<'a, I, V> where
    I: Indexer
[src]

pub fn new_empty(vec: &'a mut ItemVec<I, Option<V>>) -> Self[src]