Struct rs_graph::filtered::FilteredGraph [−][src]
pub struct FilteredGraph<'a, G, P> where
G: GraphType<'a>,
P: for<'r> Fn(&'r G::Edge) -> bool, { /* fields omitted */ }Trait Implementations
impl<'a, G, P> Directed<'a> for FilteredGraph<'a, G, P> where
G: Directed<'a>,
P: 'a + for<'r> Fn(&'r G::Edge) -> bool, [src]
impl<'a, G, P> Directed<'a> for FilteredGraph<'a, G, P> where
G: Directed<'a>,
P: 'a + for<'r> Fn(&'r G::Edge) -> bool, [src]type IncidentIt = FilteredIncidentIt<G::IncidentIt>
type IncidentIt = FilteredIncidentIt<G::IncidentIt>Type of an iterator over all incident edges.
type DirectedEdge = G::DirectedEdge
type DirectedEdge = G::DirectedEdgeType of a directed edge.
fn out_iter(&'a self, u: Self::Node) -> Self::OutIt[src]
fn out_iter(&'a self, u: Self::Node) -> Self::OutIt[src]Return a graph iterator over the edges leaving a node.
fn in_iter(&'a self, u: Self::Node) -> Self::InIt[src]
fn in_iter(&'a self, u: Self::Node) -> Self::InIt[src]Return a graph iterator over the edges leaving a node.
fn incident_iter(&'a self, u: Self::Node) -> Self::IncidentIt[src]
fn incident_iter(&'a self, u: Self::Node) -> Self::IncidentIt[src]Return an iterator over all directed edges incident with a node.
fn outedges(&'a self, u: Self::Node) -> GraphIter<'a, Self, Self::OutIt>ⓘ where
Self: Sized, [src]
fn outedges(&'a self, u: Self::Node) -> GraphIter<'a, Self, Self::OutIt>ⓘ where
Self: Sized, [src]Return an iterator over the edges leaving a node.
fn outgoing(&'a self) -> OutEdges<'a, Self> where
Self: Sized, [src]
fn outgoing(&'a self) -> OutEdges<'a, Self> where
Self: Sized, [src]Return access to the outgoing arcs via an Adjacencies trait. Read more
fn inedges(&'a self, u: Self::Node) -> GraphIter<'a, Self, Self::InIt>ⓘ where
Self: Sized, [src]
fn inedges(&'a self, u: Self::Node) -> GraphIter<'a, Self, Self::InIt>ⓘ where
Self: Sized, [src]Return an iterator over the edges leaving a node.
fn incoming(&'a self) -> InEdges<'a, Self> where
Self: Sized, [src]
fn incoming(&'a self) -> InEdges<'a, Self> where
Self: Sized, [src]Return access to the incoming arcs via an Adjacencies trait. Read more
fn incident_edges(
&'a self,
u: Self::Node
) -> GraphIter<'a, Self, Self::IncidentIt>ⓘ where
Self: Sized, [src]
fn incident_edges(
&'a self,
u: Self::Node
) -> GraphIter<'a, Self, Self::IncidentIt>ⓘ where
Self: Sized, [src]Return an iterator over all directed edges incident with a node.
impl<'a, G, P, I> GraphIterator<FilteredGraph<'a, G, P>> for Filtered<I> where
G: GraphType<'a>,
P: for<'r> Fn(&'r G::Edge) -> bool,
I: GraphIterator<G, Item = (G::Edge, G::Node)>, [src]
impl<'a, G, P, I> GraphIterator<FilteredGraph<'a, G, P>> for Filtered<I> where
G: GraphType<'a>,
P: for<'r> Fn(&'r G::Edge) -> bool,
I: GraphIterator<G, Item = (G::Edge, G::Node)>, [src]impl<'a, G, P, I> GraphIterator<FilteredGraph<'a, G, P>> for FilteredIncidentIt<I> where
G: Directed<'a>,
P: for<'r> Fn(&'r G::Edge) -> bool,
I: GraphIterator<G, Item = (G::DirectedEdge, G::Node)>, [src]
impl<'a, G, P, I> GraphIterator<FilteredGraph<'a, G, P>> for FilteredIncidentIt<I> where
G: Directed<'a>,
P: for<'r> Fn(&'r G::Edge) -> bool,
I: GraphIterator<G, Item = (G::DirectedEdge, G::Node)>, [src]impl<'a, G, P, I> GraphIterator<FilteredGraph<'a, G, P>> for FilterWrapIt<I> where
G: GraphType<'a>,
P: for<'r> Fn(&'r G::Edge) -> bool,
I: GraphIterator<G>, [src]
impl<'a, G, P, I> GraphIterator<FilteredGraph<'a, G, P>> for FilterWrapIt<I> where
G: GraphType<'a>,
P: for<'r> Fn(&'r G::Edge) -> bool,
I: GraphIterator<G>, [src]type Item = I::Item
fn next(&mut self, g: &FilteredGraph<'a, G, P>) -> Option<I::Item>[src]
fn size_hint(&self, g: &FilteredGraph<'a, G, P>) -> (usize, Option<usize>)[src]
fn count(self, g: &FilteredGraph<'a, G, P>) -> usize[src]
fn iter<'a>(self, g: &'a G) -> GraphIter<'a, G, Self>ⓘ where
G: Sized, [src]
G: Sized,
impl<'a, G, P> GraphIterator<FilteredGraph<'a, G, P>> for FilterEdgeIt<G::EdgeIt> where
G: GraphSize<'a>,
P: for<'r> Fn(&'r G::Edge) -> bool, [src]
impl<'a, G, P> GraphIterator<FilteredGraph<'a, G, P>> for FilterEdgeIt<G::EdgeIt> where
G: GraphSize<'a>,
P: for<'r> Fn(&'r G::Edge) -> bool, [src]impl<'a, G, P> GraphSize<'a> for FilteredGraph<'a, G, P> where
G: GraphSize<'a>,
P: 'a + for<'r> Fn(&'r G::Edge) -> bool, [src]
impl<'a, G, P> GraphSize<'a> for FilteredGraph<'a, G, P> where
G: GraphSize<'a>,
P: 'a + for<'r> Fn(&'r G::Edge) -> bool, [src]type NodeIt = FilterWrapIt<G::NodeIt>
type NodeIt = FilterWrapIt<G::NodeIt>Type of an iterator over all nodes.
type EdgeIt = FilterEdgeIt<G::EdgeIt>
type EdgeIt = FilterEdgeIt<G::EdgeIt>Type of an iterator over all edges.
fn nodes_iter(&'a self) -> Self::NodeIt[src]
fn nodes_iter(&'a self) -> Self::NodeIt[src]Return a graph iterator over all nodes.
fn edges_iter(&self) -> Self::EdgeIt[src]
fn edges_iter(&self) -> Self::EdgeIt[src]Return a graph iterator over all edges. Read more
fn nodes(&'a self) -> NodeIterator<'a, Self> where
Self: Sized, [src]
fn nodes(&'a self) -> NodeIterator<'a, Self> where
Self: Sized, [src]Return an iterator over all nodes.
fn edges(&'a self) -> EdgeIterator<'a, Self> where
Self: Sized, [src]
fn edges(&'a self) -> EdgeIterator<'a, Self> where
Self: Sized, [src]Return an iterator over all edges. Read more
impl<'a, G, P> GraphType<'a> for FilteredGraph<'a, G, P> where
G: GraphType<'a>,
P: 'a + for<'r> Fn(&'r G::Edge) -> bool, [src]
impl<'a, G, P> GraphType<'a> for FilteredGraph<'a, G, P> where
G: GraphType<'a>,
P: 'a + for<'r> Fn(&'r G::Edge) -> bool, [src]impl<'a, G, P> Undirected<'a> for FilteredGraph<'a, G, P> where
G: Undirected<'a>,
P: 'a + for<'r> Fn(&'r G::Edge) -> bool, [src]
impl<'a, G, P> Undirected<'a> for FilteredGraph<'a, G, P> where
G: Undirected<'a>,
P: 'a + for<'r> Fn(&'r G::Edge) -> bool, [src]fn enodes(&'a self, e: Self::Edge) -> (Self::Node, Self::Node)[src]
fn enodes(&'a self, e: Self::Edge) -> (Self::Node, Self::Node)[src]Return the nodes connected by an edge. Read more
fn neigh_iter(&'a self, u: Self::Node) -> Self::NeighIt[src]
fn neigh_iter(&'a self, u: Self::Node) -> Self::NeighIt[src]Return a graph iterator over the edges adjacent to some node.