Struct rs_graph::linkedlistgraph::LinkedListGraphBuilder[][src]

pub struct LinkedListGraphBuilder<ID, N, E> { /* fields omitted */ }

A builder for a LinkedListGraph.

The basic task is to arrange the final outgoing and incoming edges in the linked lists appropriately (i.e. first outgoing, then incoming edges).