Struct rs_graph::mcf::simplex::NetworkSimplex[][src]

pub struct NetworkSimplex<'a, G, F> {
    pub pricing: Pricing,
    pub artificial_cost: Option<F>,
    pub infinite: F,
    // some fields omitted
}

Fields

pricing: Pricingartificial_cost: Option<F>

The artificial cost value.

Should be larger than the value of any augmenting cycle. If None (the default) the artificial cost is set to (max(max(cost), 0) + 1) * n, which should be large enough.

infinite: F

The infinite flow value.

Capacities greater than or equal to this are considered unbounded and flows are considered infinite. The default is F::max_value(). For floating-point types F::infinity() can be used as well.

Implementations

impl<'a, G, F> NetworkSimplex<'a, G, F> where
    G: IndexDigraph<'a>,
    F: NumCast + NumAssign + Signed + PartialOrd + Copy + FromPrimitive
[src]

pub fn num_iterations(&self) -> usize[src]