Module rs_graph::steinlib [−][src]
Reading files in SteinLib format.
This reader supports the following extensions to the SteinLib format:
- Additional drawing attributes section
ⓘ
SECTION Drawing A <u> <v> <attribute>... E <u> <v> <attribute>... END
This is a list of drawing attributes for each edge. Possible attributes are
blthe arc should be bend to the leftbrthe arc should be bend to the right
Structs
| Instance | An SteinLib instance. |
Enums
| EdgeAttr | Edge drawing attributes. |
| Error |
Functions
| read |
Type Definitions
| Result | Type of values with optional error code. |