Struct rs_graph::vec::ItemVec [−][src]
pub struct ItemVec<T, Idx>(_, _);
New type wrapper around Vec<T> to be indexed by nodes and edges.
This thin wrapper allows Vec<T> to be used an NodeMap or
EdgeMap for implementors of NumberedGraph directly.
Methods
impl<T, Idx> ItemVec<T, Idx>[src]
impl<T, Idx> ItemVec<T, Idx>Trait Implementations
impl<T: Debug, Idx: Debug> Debug for ItemVec<T, Idx>[src]
impl<T: Debug, Idx: Debug> Debug for ItemVec<T, Idx>fn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl<T: Clone, Idx: Clone> Clone for ItemVec<T, Idx>[src]
impl<T: Clone, Idx: Clone> Clone for ItemVec<T, Idx>fn clone(&self) -> ItemVec<T, Idx>[src]
fn clone(&self) -> ItemVec<T, Idx>Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl<T: PartialEq, Idx: PartialEq> PartialEq for ItemVec<T, Idx>[src]
impl<T: PartialEq, Idx: PartialEq> PartialEq for ItemVec<T, Idx>fn eq(&self, other: &ItemVec<T, Idx>) -> bool[src]
fn eq(&self, other: &ItemVec<T, Idx>) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &ItemVec<T, Idx>) -> bool[src]
fn ne(&self, other: &ItemVec<T, Idx>) -> boolThis method tests for !=.
impl<T: Eq, Idx: Eq> Eq for ItemVec<T, Idx>[src]
impl<T: Eq, Idx: Eq> Eq for ItemVec<T, Idx>impl<T: PartialOrd, Idx: PartialOrd> PartialOrd for ItemVec<T, Idx>[src]
impl<T: PartialOrd, Idx: PartialOrd> PartialOrd for ItemVec<T, Idx>fn partial_cmp(&self, other: &ItemVec<T, Idx>) -> Option<Ordering>[src]
fn partial_cmp(&self, other: &ItemVec<T, Idx>) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
fn lt(&self, other: &ItemVec<T, Idx>) -> bool[src]
fn lt(&self, other: &ItemVec<T, Idx>) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
fn le(&self, other: &ItemVec<T, Idx>) -> bool[src]
fn le(&self, other: &ItemVec<T, Idx>) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
fn gt(&self, other: &ItemVec<T, Idx>) -> bool[src]
fn gt(&self, other: &ItemVec<T, Idx>) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
fn ge(&self, other: &ItemVec<T, Idx>) -> bool[src]
fn ge(&self, other: &ItemVec<T, Idx>) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl<T: Ord, Idx: Ord> Ord for ItemVec<T, Idx>[src]
impl<T: Ord, Idx: Ord> Ord for ItemVec<T, Idx>fn cmp(&self, other: &ItemVec<T, Idx>) -> Ordering[src]
fn cmp(&self, other: &ItemVec<T, Idx>) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl<T, Idx> From<Vec<T>> for ItemVec<T, Idx>[src]
impl<T, Idx> From<Vec<T>> for ItemVec<T, Idx>impl<T, Idx> Deref for ItemVec<T, Idx>[src]
impl<T, Idx> Deref for ItemVec<T, Idx>type Target = ItemSlice<T, Idx>
The resulting type after dereferencing.
fn deref(&self) -> &ItemSlice<T, Idx>[src]
fn deref(&self) -> &ItemSlice<T, Idx>Dereferences the value.
impl<T, Idx> DerefMut for ItemVec<T, Idx>[src]
impl<T, Idx> DerefMut for ItemVec<T, Idx>impl<T, I, Idx> Index<I> for ItemVec<T, Idx> where
Idx: NumberedIndexer<I>, [src]
impl<T, I, Idx> Index<I> for ItemVec<T, Idx> where
Idx: NumberedIndexer<I>, type Output = T
The returned type after indexing.
fn index(&self, item: I) -> &T[src]
fn index(&self, item: I) -> &TPerforms the indexing (container[index]) operation.
impl<T, I, Idx> IndexMut<I> for ItemVec<T, Idx> where
Idx: NumberedIndexer<I>, [src]
impl<T, I, Idx> IndexMut<I> for ItemVec<T, Idx> where
Idx: NumberedIndexer<I>, fn index_mut(&mut self, item: I) -> &mut T[src]
fn index_mut(&mut self, item: I) -> &mut TPerforms the mutable indexing (container[index]) operation.
impl<'a, T, I, Idx> Index<I> for &'a ItemVec<T, Idx> where
Idx: NumberedIndexer<I>, [src]
impl<'a, T, I, Idx> Index<I> for &'a ItemVec<T, Idx> where
Idx: NumberedIndexer<I>, type Output = T
The returned type after indexing.
fn index(&self, item: I) -> &T[src]
fn index(&self, item: I) -> &TPerforms the indexing (container[index]) operation.
impl<'a, T, I, Idx> Index<I> for &'a mut ItemVec<T, Idx> where
Idx: NumberedIndexer<I>, [src]
impl<'a, T, I, Idx> Index<I> for &'a mut ItemVec<T, Idx> where
Idx: NumberedIndexer<I>, type Output = T
The returned type after indexing.
fn index(&self, item: I) -> &T[src]
fn index(&self, item: I) -> &TPerforms the indexing (container[index]) operation.
impl<'a, T, I, Idx> IndexMut<I> for &'a mut ItemVec<T, Idx> where
Idx: NumberedIndexer<I>, [src]
impl<'a, T, I, Idx> IndexMut<I> for &'a mut ItemVec<T, Idx> where
Idx: NumberedIndexer<I>,