Struct rs_graph::vecgraph::VecGraphBuilder[][src]

pub struct VecGraphBuilder<ID> { /* fields omitted */ }

A builder for a VecGraph.

The basic task is to arrange the final outgoing and incoming edges in the linked lists appropriately (i.e. first outgoing, then incoming edges).