Enum rs_graph::adapters::network::NetworkEdge [−][src]
pub enum NetworkEdge<E> {
Forward(E),
Backward(E),
}A network edge.
This is either the forward or the backward edge of the original edge.
Variants
Implementations
impl<E> NetworkEdge<E> where
E: Clone + Eq, [src]
impl<E> NetworkEdge<E> where
E: Clone + Eq, [src]pub fn new(e: E) -> Self[src]
Return the forward edge corresponding to the given underlying edge.
pub fn is_forward(&self) -> bool[src]
Return true if this is the forward edge.
pub fn is_backward(&self) -> bool[src]
Return true if this is the backward edge.
pub fn is_reverse(&self, e: Self) -> bool[src]
Return true if e is the reverse edge of self.
pub fn reverse(&self) -> Self[src]
Return the reverse edge of this edge.
pub fn forward(&self) -> Self[src]
Return the forward edge of self.
If this is already the forward edge then self is returned and
self.reverse() otherwise.
pub fn backward(&self) -> Self[src]
Return the backward edge of self.
If this is already the backward edge then self is returned and
self.reverse() otherwise.
pub fn edge(&self) -> E[src]
Return the edge of the underlying graph.