Struct rs_graph::collections::ItemVecMap [−][src]
pub struct ItemVecMap<'a, I, V> { /* fields omitted */ }A thin wrapper around a ItemVec<_, Option<V>>.
Such a vector can be used as ItemMap<_, V> with a field being None if
and only if the corresponding key is not contained in the map.
Implementations
impl<'a, I, V> ItemVecMap<'a, I, V> where
I: Indexer, [src]
impl<'a, I, V> ItemVecMap<'a, I, V> where
I: Indexer, [src]Trait Implementations
impl<'a, I, V> ItemMap<<I as Indexer>::Idx, V> for ItemVecMap<'a, I, V> where
I: Indexer,
I::Idx: Copy, [src]
impl<'a, I, V> ItemMap<<I as Indexer>::Idx, V> for ItemVecMap<'a, I, V> where
I: Indexer,
I::Idx: Copy, [src]fn insert_or_replace(&mut self, key: I::Idx, value: V) -> bool[src]
fn insert_or_replace(&mut self, key: I::Idx, value: V) -> bool[src]Add one item to the map. Read more
fn get(&self, key: I::Idx) -> Option<&V>[src]
fn get(&self, key: I::Idx) -> Option<&V>[src]Return a read-only reference to the element with the given key.